### Name: ezANOVA
### Title: Function to perform a factorial ANOVA
### Aliases: ezANOVA


### ** Examples

#Read in the ANT data (see ?ANT).
data(ANT)

#Show summaries of the ANT data.
head(ANT)
str(ANT)
summary(ANT)

#Compute some useful statistics per cell.
cell_stats = ddply(
        .data = ANT
        , .variables = .( sid , group , cue , flanker )
        , .fun <- function(x){
                #Compute error rate as percent.
                error_rate = (1-mean(x$acc))*100
                #Compute mean RT (only accurate trials).
                mean_rt = mean(x$rt[x$acc==1])
                #Compute SD RT (only accurate trials).
                sd_rt = sd(x$rt[x$acc==1])
                return(c(error_rate=error_rate,mean_rt=mean_rt,sd_rt=sd_rt))
        }
)

#Run an ANOVA on the mean_rt data.
mean_rt_anova = ezANOVA(
        data = cell_stats
        , dv = .(mean_rt)
        , sid = .(sid)
        , within = .(cue,flanker)
        , between = .(group)
)

#Show the ANOVA & assumption tests.
print(mean_rt_anova)

#Run an ANOVA on the mean_rt data, ignoring group.
mean_rt_anova2 = ezANOVA(
        data = cell_stats
        , dv = .(mean_rt)
        , sid = .(sid)
        , within = .(cue,flanker)
)

#Show the ANOVA & assumption tests.
print(mean_rt_anova2)

#Run a purely between-Ss ANOVA on the mean_rt data.
##Note how ezANOVA automatically collapses the unspecified within-Ss data.
mean_rt_anova3 = ezANOVA(
        data = cell_stats
        , dv = .(mean_rt)
        , sid = .(sid)
        , between = .(group)
)

#Show the ANOVA & assumption tests.
print(mean_rt_anova3)



