### Name: ezPerm
### Title: Function to perform a factorial permutation test
### Aliases: ezPerm


### ** Examples

#Read in the ANT data (see ?ANT).
data(ANT)

#Show summaries of the ANT data.
head(ANT)
str(ANT)
summary(ANT)

#Compute some useful statistics per cell.
cell_stats = ddply(
        .data = ANT
        , .variables = .( sid , group , cue , flanker )
        , .fun <- function(x){
                #Compute error rate as percent.
                error_rate = (1-mean(x$acc))*100
                #Compute mean RT (only accurate trials).
                mean_rt = mean(x$rt[x$acc==1])
                #Compute SD RT (only accurate trials).
                sd_rt = sd(x$rt[x$acc==1])
                return(c(error_rate=error_rate,mean_rt=mean_rt,sd_rt=sd_rt))
        }
)

#Compute the grand mean RT per Ss.
gmrt = ddply(
        .data = cell_stats
        , .variables = .( sid , group )
        , .fun <- function(x){
                y = mean(x$mean_rt)
                return(c(y=y))
        }
)

#Run a purely between-Ss ANOVA on the mean_rt data. 
# (Completes after ~30s on a 2.4GHz processor).
mean_rt_perm = ezPerm(
        data = gmrt
        , dv = .(y)
        , sid = .(sid)
        , between = .(group)
        , perms = 1e3
)

#Show the Permutation test.
print(mean_rt_perm)



